/*******************************************************************************
 * Copyright (c) 2000, 2011 IBM Corporation and others.
 *
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.ui.tests.zoom;

import org.junit.Ignore;
import org.junit.runner.RunWith;
import org.junit.runners.Suite;

/**
 * A test suite to test the zooming behavior of Eclipse.
 */
@Ignore
@RunWith(Suite.class)
@Suite.SuiteClasses({
	ZoomedViewActivateTest.class,
	ZoomedEditorCloseTest.class,
	ZoomedViewCloseTest.class,
	ShowViewTest.class,
	OpenEditorTest.class,
})
public class ZoomTestSuite {
}
